==> qore-2.0.0.tar.bz2: qore-2.0.0/docs/modules/DataProvider/html/struct_data_provider_1_1_data_provider_app_info.js <==
var struct_data_provider_1_1_data_provider_app_info =
[
    [ "desc", "struct_data_provider_1_1_data_provider_app_info.html#a36731b3bc7eb1b2c5f043e1bd8d525ff", null ],
    [ "display_name", "struct_data_provider_1_1_data_provider_app_info.html#a37454f8bb453a72afc6cd7cc43160140", null ],
    [ "dynamic", "struct_data_provider_1_1_data_provider_app_info.html#a44934f1c30445b20710e863fb1173ffe", null ],
    [ "hidden", "struct_data_provider_1_1_data_provider_app_info.html#a49ea9df9bfff82afb670ea263f5f100b", null ],
    [ "info", "struct_data_provider_1_1_data_provider_app_info.html#a3f6b8f6462bf341ef4ee6ff8a8ac6dad", null ],
    [ "legal", "struct_data_provider_1_1_data_provider_app_info.html#a6bcca254c32df8355460b87b976e5354", null ],
    [ "logo", "struct_data_provider_1_1_data_provider_app_info.html#a1b07d2ea189b3fa7e65cee9099aed82b", null ],
    [ "logo_file_name", "struct_data_provider_1_1_data_provider_app_info.html#a82bc82074e048c68e3db71559cfd2fd2", null ],
    [ "logo_mime_type", "struct_data_provider_1_1_data_provider_app_info.html#a527f80b1f7c5077d2ef09f8a63b7083f", null ],
    [ "name", "struct_data_provider_1_1_data_provider_app_info.html#a6315c2294c4b58e45cff158498c3df73", null ],
    [ "scheme", "struct_data_provider_1_1_data_provider_app_info.html#a53168dbe39ecbaf535044824a4d584bb", null ],
    [ "short_desc", "struct_data_provider_1_1_data_provider_app_info.html#a1a65eb0e41da07985f978ab793daa9dc", null ],
    [ "supports_apis", "struct_data_provider_1_1_data_provider_app_info.html#ab4cabf3cb886bf5f8a0b1f02222a4b29", null ],
    [ "supports_create", "struct_data_provider_1_1_data_provider_app_info.html#accd3ed5ba3d3605d0bd26dc70f088d36", null ],
    [ "supports_delete", "struct_data_provider_1_1_data_provider_app_info.html#ae1a9fdd56933b2a2a7ceabb474e7c277", null ],
    [ "supports_events", "struct_data_provider_1_1_data_provider_app_info.html#a54c1a461dd44b93052d22cdc23076540", null ],
    [ "supports_find", "struct_data_provider_1_1_data_provider_app_info.html#ad02abd7c446a81899f5947b833cb17ff", null ],
    [ "supports_find_single", "struct_data_provider_1_1_data_provider_app_info.html#a72a9a2f7cfae8da965376ff25d3672ba", null ],
    [ "supports_messages", "struct_data_provider_1_1_data_provider_app_info.html#a27101ed95b6ed3f32daf73faae8b21f7", null ],
    [ "supports_update", "struct_data_provider_1_1_data_provider_app_info.html#a4ef95cd7fcf0e13823f8222d4c12cb2f", null ],
    [ "supports_upsert", "struct_data_provider_1_1_data_provider_app_info.html#a9343cbe5d2116f1ba145fa58e8d74394", null ]
];

==> qore-2.2.0.tar.bz2: qore-2.2.0/docs/modules/DataProvider/html/struct_data_provider_1_1_data_provider_app_info.js <==
var struct_data_provider_1_1_data_provider_app_info =
[
    [ "desc", "struct_data_provider_1_1_data_provider_app_info.html#a36731b3bc7eb1b2c5f043e1bd8d525ff", null ],
    [ "display_name", "struct_data_provider_1_1_data_provider_app_info.html#a37454f8bb453a72afc6cd7cc43160140", null ],
    [ "dynamic", "struct_data_provider_1_1_data_provider_app_info.html#a44934f1c30445b20710e863fb1173ffe", null ],
    [ "group", "struct_data_provider_1_1_data_provider_app_info.html#a50b5d5d38ebbaa55abff818f3c26e79d", null ],
    [ "hidden", "struct_data_provider_1_1_data_provider_app_info.html#a49ea9df9bfff82afb670ea263f5f100b", null ],
    [ "info", "struct_data_provider_1_1_data_provider_app_info.html#a3f6b8f6462bf341ef4ee6ff8a8ac6dad", null ],
    [ "legal", "struct_data_provider_1_1_data_provider_app_info.html#a6bcca254c32df8355460b87b976e5354", null ],
    [ "logo", "struct_data_provider_1_1_data_provider_app_info.html#a1b07d2ea189b3fa7e65cee9099aed82b", null ],
    [ "logo_file_name", "struct_data_provider_1_1_data_provider_app_info.html#a82bc82074e048c68e3db71559cfd2fd2", null ],
    [ "logo_mime_type", "struct_data_provider_1_1_data_provider_app_info.html#a527f80b1f7c5077d2ef09f8a63b7083f", null ],
    [ "name", "struct_data_provider_1_1_data_provider_app_info.html#a6315c2294c4b58e45cff158498c3df73", null ],
    [ "scheme", "struct_data_provider_1_1_data_provider_app_info.html#a53168dbe39ecbaf535044824a4d584bb", null ],
    [ "short_desc", "struct_data_provider_1_1_data_provider_app_info.html#a1a65eb0e41da07985f978ab793daa9dc", null ],
    [ "supports_apis", "struct_data_provider_1_1_data_provider_app_info.html#ab4cabf3cb886bf5f8a0b1f02222a4b29", null ],
    [ "supports_create", "struct_data_provider_1_1_data_provider_app_info.html#accd3ed5ba3d3605d0bd26dc70f088d36", null ],
    [ "supports_delete", "struct_data_provider_1_1_data_provider_app_info.html#ae1a9fdd56933b2a2a7ceabb474e7c277", null ],
    [ "supports_events", "struct_data_provider_1_1_data_provider_app_info.html#a54c1a461dd44b93052d22cdc23076540", null ],
    [ "supports_find", "struct_data_provider_1_1_data_provider_app_info.html#ad02abd7c446a81899f5947b833cb17ff", null ],
    [ "supports_find_single", "struct_data_provider_1_1_data_provider_app_info.html#a72a9a2f7cfae8da965376ff25d3672ba", null ],
    [ "supports_messages", "struct_data_provider_1_1_data_provider_app_info.html#a27101ed95b6ed3f32daf73faae8b21f7", null ],
    [ "supports_update", "struct_data_provider_1_1_data_provider_app_info.html#a4ef95cd7fcf0e13823f8222d4c12cb2f", null ],
    [ "supports_upsert", "struct_data_provider_1_1_data_provider_app_info.html#a9343cbe5d2116f1ba145fa58e8d74394", null ]
];
